@@ -5,7 +5,7 @@ import os
 import re
 from collections import Counter
 from copy import deepcopy
-from ctypes import c_size_t
+from hashlib import blake2b
 from io import BytesIO
 from json import JSONDecodeError
 from multiprocessing import Lock
@@ -104,7 +104,8 @@ class DocumentPickleRepository:
     def __init__(self, dir_path: Path, common_dir_path: Path = None):
         if not dir_path.is_dir():
             raise NotADirectoryError(f"The given path '{dir_path}' does not point to an existing directory!")
-        self.file_path = dir_path / f'.{c_size_t(hash(common_dir_path)).value}.pdef'
+        path_hash = blake2b(str(common_dir_path).encode(), digest_size=16).hexdigest()
+        self.file_path = dir_path / f'.{path_hash}.pdef'
 
     def save(self, docs: set[models.Document]):
         with self.file_path.open('wb') as file:
